@@ -34,13 +34,14 @@
 #include <QtGui/QLabel>
 #include <QtGui/QSortFilterProxyModel>
 
-#include <KGenericFactory>
+#include <KPluginFactory>
 #include <KIcon>
 #include <KLocale>
 #include <KMessageBox>
 #include <KAboutData>
 #include <KMessageWidget>
 #include <KPixmapSequenceOverlayPainter>
+#include <KDebug>
 
 #include <TelepathyQt/Account>
 #include <TelepathyQt/AccountFactory>
@@ -61,7 +62,7 @@ KCMTelepathyAccounts::KCMTelepathyAccounts(QWidget *parent, const QVariantList&
    m_accountsListModel(0)
 {
     //set up component data.
-    KAboutData *aboutData = new KAboutData(I18N_NOOP("telepathy_accounts"), 0, ki18n("Instant Messaging and VOIP Accounts"), "0.3", KLocalizedString(), KAboutData::License_GPL);
+    KAboutData *aboutData = new KAboutData(I18N_NOOP("telepathy_accounts"), 0, ki18n("Instant Messaging and VOIP Accounts"), "0.4", KLocalizedString(), KAboutData::License_GPL);
 
     aboutData->addAuthor(ki18n("George Goldberg"), ki18n("Developer"),"grundleborg@googlemail.com");
     aboutData->addAuthor(ki18n("David Edmundson"), ki18n("Developer"), "david@davidedmundson.co.uk");
@@ -133,7 +134,7 @@ KCMTelepathyAccounts::KCMTelepathyAccounts(QWidget *parent, const QVariantList&
     AccountsListDelegate* salutDelegate = new AccountsListDelegate(m_ui->salutListView, this);
     m_ui->salutListView->setItemDelegate(salutDelegate);
 
-    int height = salutDelegate->sizeHint(QStyleOptionViewItem(), m_salutFilterModel->index(0,0)).height() + 4*2;
+    int height = salutDelegate->sizeHint(QStyleOptionViewItem(), m_salutFilterModel->index(0,0)).height() + 3*2;
     m_ui->salutListView->setMinimumHeight(height);
     m_ui->salutEnableFrame->setMinimumHeight(height);
 
@@ -340,9 +341,7 @@ void KCMTelepathyAccounts::onRemoveAccountClicked()
                                         QString(), KMessageBox::Notify | KMessageBox::Dangerous) == KMessageBox::Continue)
     {
         AccountItem *item = index.data(AccountsListModel::AccountItemRole).value<AccountItem*>();
-        KTp::WalletInterface wallet(this->effectiveWinId());
-        wallet.removeAccount(item->account());
-
+        KTp::WalletInterface::removeAccount(item->account());
         m_accountsListModel->removeAccount(m_currentModel->mapToSource(index));
     }
 }
